/* ------------------------------------------------------------------------- *
 * An example SAS program for Stats 506.
 *
 * This file uses the 2020 RECS data from:
 *   recs2020_public_v5.sas7bdat
 *
 *   http://www.eia.gov/consumption/residential/data/2020/
 *        index.cfm?view=microdata
 *
 * I demonstrate two procs for descriptive statistics:
 *  proc means and proc freq
 *
 * Not shown here but similar: proc univariate
 *
 * Author: James Henderson
 * Updated: Oct 18, 2023
 * ------------------------------------------------------------------------- *
*/
/* 79: --------------------------------------------------------------------- */

/* data libraries for reading/writing data: -------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data;
%let out_path = ~/my_shared_file_links/jbhender0/output_data; 
libname in_lib "&in_path."; 
libname out_lib "&out_path.";

/* data prep: -------------------------------------------------------------- */
data recs;
 set in_lib.recs2020_public_v5;

/* proc means: ------------------------------------------------------------- */
proc means data=recs;
 var cdd65; 
 class regionc;
 title "Example 10a";
run;

/* proc sort for use with 'by' in proc means */
proc sort data=recs;
 by regionc;

proc means data=recs;
 var cdd65;
 by regionc;
 title "Example 10b";
run;

proc contents data=recs;

/* twice stratified using "by" */
proc sort data=recs;
 by regionc uatyp10;

proc means;
 var cdd65;
 by regionc uatyp10;
 title "Example 10c"; 
run; 

proc means;
 var cdd65 hdd65;
 by regionc uatyp10; 
 title "Example 10d"; 
run;

proc means;
 var cdd65 hdd65;
 class uatyp10;
 by regionc;
 title "Example 10e"; 
run;

proc means data=recs mean clm maxdec=1;
 var cdd65 hdd65;
 class regionc uatyp10;
 title "Example 10f"; 
run;


proc means data=recs mean clm maxdec=1;
 var cdd65 hdd65;
 class regionc uatyp10;
 output out=out_lib.recs2020_mean_cdd_hdd
   mean=mean
   lclm=lwr
   uclm=upr
   ;
 title "Example 10g"; 
run;

/* proc freq: -------------------------------------------------------------- */

proc freq data=recs;
  tables uatyp10 / out=tab_uatyp10;  
  title "Example 10h - i";
  
proc print data=tab_uatyp10; 
  title "Example 10h - ii"; 
run;

/* proc summary: ----------------------------------------------------------- */
proc summary data=recs;
 class regionc;
 output out=meanstats
   mean(kwh) = mean_kwh
   std(kwh) = std_kwh;
  title "Example 10i - i"; 
run;

proc print data=meanstats;
  title "Example 10i - ii"; 
run;

/* 79: --------------------------------------------------------------------- */