/* ------------------------------------------------------------------------- *
 * An example SAS program for Stats 506.
 *
 * This file uses RECS data from:
 *   recs2009_public_v4.sas7bdat
 * 
 *   http://www.eia.gov/consumption/residential/data/2009/index.cfm
 *     ?view=microdata
 *
 * Then demonstrates proc tabulate for descriptive statistics.
 * 
 * Author: James Henderson
 * Updated: Oct 19, 2020
 * ------------------------------------------------------------------------- *
*/
/* 79: --------------------------------------------------------------------- */

/* data library for reading/writing data: ---------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data;
%let out_path = ~/my_shared_file_links/jbhender0/output_data; 
libname in_lib "&in_path."; 
libname out_lib "&out_path.";

/* create a short name and working copy for recs data: --------------------- */
data recs;
 set in_lib.recs2020_public_v5;

/* data step to create urban indicator: ------------------------------------ */
data recs;
 set recs;
 urban=0;
 if uatyp10='U' then urban=1;
run; 

/* Tabulate: --------------------------------------------------------------- */

/* get max, min, and Nobs for regionC */
proc tabulate data=recs;
 var hdd65;
 table hdd65*N hdd65*max hdd65*min;
 title "Example 11a"; 
run;

/* var vs class */
proc tabulate data=recs;
 var urban;
 class uatyp10;
 table urban*sum uatyp10*N urban*N;
 title "Example 11b"; 
run;

/* grouped tables */
proc tabulate data=recs;
 var cdd65; 
 class regionc;
 table regionc, N cdd65*mean; 
 title "Example 11c";
run; 

proc tabulate data=recs;
 var cdd65;
 class regionc;
 /*table cdd65*N*regionc cdd65*mean*regionc;*/
 table N*regionc cdd65*mean*regionc;
 title "Example 11d"; 
run;

/* twice stratified tables */
proc tabulate data=recs;
 var cdd65;
 class regionc uatyp10;
 table regionc, cdd65*mean*uatyp10;
 title "Example 11e";
run;

