/* ------------------------------------------------------------------------- *
 * An example SAS program for Stats 506.
 *
 * A demonstration of proc sql. 
 *
 * Repeat example 7, using proc sql and replicate weights to compute
 * replicate estimates of the effective sample sizes. 
 *
 * Then compute a Jackknife variance estimate using the replicate weights. 
 * 
 * Author: James Henderson
 * Updated: Oct 11, 2023
 * ------------------------------------------------------------------------- *
*/
/* 79: --------------------------------------------------------------------- */

/* data library for reading/writing data: ---------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data;
%let out_path = ~/my_shared_file_links/jbhender0/output_data; 
libname in_lib "&in_path."; 
libname out_lib "&out_path.";

/* effective sample size and replicate estimates for each census region: --- */
proc sql;
  
  /* merge census region into a copy of long format replicate weights */
  create table w_long as
  select a.*, b.regionc, w_sq_r = a.w_r * a.w_r
  from out_lib.w2020_long a
  left join in_lib.recs2020_public_v5 b
  on a.doeid = b.doeid;
  
  /* point estimate of ess */
  create table ess_pe as 
  select regionc, sum(nweight) * sum(nweight) / sum(nweight * nweight) as ess
  from in_lib.recs2020_public_v5
  group by regionc; 
  
  /* replicate estimatess of ess */
  create table ess_repl as
  select regionc, replicate, sum(w_r) * sum(w_r) / sum(w_r * w_r) as ess_r
  from w_long
  group by regionc, replicate;

quit; 
run;

/* jackknife variance estimate: -------------------------------------------- */
%let z = 1.96;

proc sql;

  /* residual sum of squares */
  create table ess_rss as
  select a.regionc, sum((b.ess - a.ess_r)**2) as rss, count(a.regionc) as n
  from ess_repl a
  left join ess_pe b
  on a.regionc = b.regionc
  group by a.regionc;

  create table ess_temp as
  select
    a.regionc,
    b.ess,
    sqrt((a.n - 1) / a.n * rss) as se
  from ess_rss a
  left join ess_pe b
  on a.regionc = b.regionc;
  
  create table ess as
  select regionc, ess, se, ess - &z. * se as lwr, ess + &z. * se as upr
  from ess_temp;
  
quit;
run; 

/* clean up intermediate tables: ------------------------------------------ */
proc sql;
	drop table ess_temp, ess_rss, ess_pe, ess_repl; 
quit;
run;
 