/* ------------------------------------------------------------------------- *
 * An example SAS macro for Stats 506.
 *
 * The macro "csvexport" calls proc export for a specified dataset in
 * (optionally) a specified library. 
 *
 * Author: James Henderson
 * Updated: Oct 18, 2023
 * ------------------------------------------------------------------------- *
*/
/* 79: --------------------------------------------------------------------- */

/* data libraries for reading/writing data: -------------------------------- */
%let in_path = ~/my_shared_file_links/jbhender0/input_data;
%let out_path = ~/my_shared_file_links/jbhender0/output_data; 
libname in_lib "&in_path."; 
libname out_lib "&out_path.";

/* define csvexport: ------------------------------------------------------- */
%macro csvexport(dataset, path=., lib=work);
 /* exports a sas dataset to a csv file
  * inputs:
  *  dataset - the name of the sas dataset to export
  *  path - where to write the sas dataset, defaults to the current directory
  *          this default may not work outside of a Unix-alike system
  *  lib - the SAS library where dataset is found 
  */
 proc export
   data = &lib..&dataset.
   /*outfile = "./&dataset..csv"*/
   outfile = "&path./&dataset..csv"
   dbms = dlm
   replace;
  delimiter=",";
 run;
%mend csvexport;
run;

/* invoke the macro: ------------------------------------------------------- */
%csvexport(ess_by_region_recs2020, path=&out_path., lib=out_lib);
run;

/* fails because we try to call a keyword parameters by position */
/* %csvexport(ess_by_region_recs2020, &out_path., out_lib); */

/* Exercise: ---------------------------------------------------------------- */
/* Modify the macro to optionally allow the csv file to have a
 *  different file stem than the SAS dataset. 
 */

%macro csvexport2(dataset, path=., out_name="", lib=work);
 /* exports a sas dataset to a csv file
  * inputs:
  *  dataset - the name of the sas dataset to export
  *  path - where to write the sas dataset, defaults to the current directory
  *          this default may not work outside of a Unix-alike system
  *  lib - the SAS library where dataset is found 
  */
 
 %if &out_name.="" %then 
   %let out_name=&dataset.;
   
 proc export
   data = &lib..&dataset.
   /*outfile = "./&dataset..csv"*/
   outfile = "&path./&out_name..csv"
   dbms = dlm
   replace;
  delimiter=",";
 run;
%mend csvexport2;
run;

%csvexport2(ess_by_region_recs2020, path=&out_path., lib=out_lib);
%csvexport2(
  ess_by_region_recs2020,
  path=&out_path.,
  out_name=test,
  lib=out_lib
);
run;
/* 79: --------------------------------------------------------------------- */
   